==> ACE+TAO-6.3.3.tar.bz2: ACE_wrappers/TAO/tests/CodeSets/libs/IBM1047_ISO8859/Wchar_IBM1047_ISO8859_Translator.cpp <==
// -*- C++ -*-

//=============================================================================
/**
 *  @file    Wchar_IBM1047_ISO8859_Translator.cpp
 *
 *  Defines the arrays required to convert between ISO8859 (aka
 *  Latin/1) and IBM1047 (aka EBCDIC).
 *
 *  @author Mahesh Vedantam (mahesh@ociweb.com)
 */
//=============================================================================


#include "Wchar_IBM1047_ISO8859_Translator.h"

// ****************************************************************

WIBM1047_ISO8859::WIBM1047_ISO8859 (void)
{

}

WIBM1047_ISO8859::~WIBM1047_ISO8859 (void)
{

}

// = Documented in $ACE_ROOT/ace/CDR_Stream.h
ACE_CDR::Boolean WIBM1047_ISO8859::read_wchar (ACE_InputCDR &,
                                               ACE_CDR::WChar &)
{
  return 0;
}

ACE_CDR::Boolean WIBM1047_ISO8859::read_wstring (ACE_InputCDR &,
                                                 ACE_CDR::WChar *&)
{
  return 0;
}

ACE_CDR::Boolean WIBM1047_ISO8859::read_wchar_array (ACE_InputCDR &,
                                                     ACE_CDR::WChar *,
                                                     ACE_CDR::ULong)
{
  return 0;
}

ACE_CDR::Boolean WIBM1047_ISO8859::write_wchar (ACE_OutputCDR &,
                                       ACE_CDR::WChar)
{
  return 0;
}
ACE_CDR::Boolean WIBM1047_ISO8859::write_wstring (ACE_OutputCDR &,
                                         ACE_CDR::ULong,
                                         const ACE_CDR::WChar *)
{
  return 0;
}
ACE_CDR::Boolean WIBM1047_ISO8859::write_wchar_array (ACE_OutputCDR &,
                                             const ACE_CDR::WChar *,
                                             ACE_CDR::ULong)
{
  return 0;
}

==> ACE+TAO-8.0.0.tar.bz2: ACE_wrappers/TAO/tests/CodeSets/libs/IBM1047_ISO8859/Wchar_IBM1047_ISO8859_Translator.cpp <==
// -*- C++ -*-

//=============================================================================
/**
 *  @file    Wchar_IBM1047_ISO8859_Translator.cpp
 *
 *  Defines the arrays required to convert between ISO8859 (aka
 *  Latin/1) and IBM1047 (aka EBCDIC).
 *
 *  @author Mahesh Vedantam (mahesh@ociweb.com)
 */
//=============================================================================


#include "Wchar_IBM1047_ISO8859_Translator.h"

// ****************************************************************

WIBM1047_ISO8859::WIBM1047_ISO8859 ()
{
}

WIBM1047_ISO8859::~WIBM1047_ISO8859 ()
{
}

// = Documented in $ACE_ROOT/ace/CDR_Stream.h
ACE_CDR::Boolean WIBM1047_ISO8859::read_wchar (ACE_InputCDR &,
                                               ACE_CDR::WChar &)
{
  return 0;
}

ACE_CDR::Boolean WIBM1047_ISO8859::read_wstring (ACE_InputCDR &,
                                                 ACE_CDR::WChar *&)
{
  return 0;
}

ACE_CDR::Boolean WIBM1047_ISO8859::read_wchar_array (ACE_InputCDR &,
                                                     ACE_CDR::WChar *,
                                                     ACE_CDR::ULong)
{
  return 0;
}

ACE_CDR::Boolean WIBM1047_ISO8859::write_wchar (ACE_OutputCDR &,
                                       ACE_CDR::WChar)
{
  return 0;
}
ACE_CDR::Boolean WIBM1047_ISO8859::write_wstring (ACE_OutputCDR &,
                                         ACE_CDR::ULong,
                                         const ACE_CDR::WChar *)
{
  return 0;
}
ACE_CDR::Boolean WIBM1047_ISO8859::write_wchar_array (ACE_OutputCDR &,
                                             const ACE_CDR::WChar *,
                                             ACE_CDR::ULong)
{
  return 0;
}
